@@ -93,7 +93,7 @@ class DApi2(object):
             msg = self.sendMessage(msg)
             for i, reg in enumerate(regs):
                 v = msg.getData(i*REG_SIZE, REG_SIZE)
-                reg.set(v)
+                reg.internalSet(v)
         
         if len(regs) == 0:
             return 
@@ -147,7 +147,7 @@ class DApi2(object):
             msg = self.sendMessage(msg)
             for i, reg in enumerate(regs):
                 v = msg.getData(i, REG_SIZE)
-                reg.set(v)
+                reg.internalSet(v)
         
         
         regs.sort() 
@@ -164,7 +164,7 @@ class DApi2(object):
         :param int value: The new value of the register before writing it. 
         '''
         if value is not None:
-            reg.set(value)
+            reg.internalSet(value)
         self.writeRegs([reg])
         
     def syncRegs(self):
