@@ -21,4 +21,8 @@ from .factory import DBoardFactory
 from .workspace import BaseWorkspace, StandbyWorkspace, Workspace, WorkspacesContainer
 from .generic import GenericBoard
 from .mb30 import Board30
-from .mb92 import Board92 
\ No newline at end of file
+from .mb92 import Board92 
+
+
+def getBoardTypes():
+    return sorted(list(DBoard.getSubclasses()), key=lambda x: x.getCode())
\ No newline at end of file
