@@ -37,33 +37,43 @@ class BaseDBoard(object):
     
     '''
     
-    number = None
+    number = '--'
     '''Board type number (str)'''
+    
+    ext = None
+    '''Board type extention (str)'''
      
     wait_after_reprogramming = 8.0 #[s]
     '''Timeout after programming to reconnect to the board expressed in second.'''
     
-    # @classmethod
-    # def allSubclasses(cls):
-        # '''Class method allowing to establish the list of all the child classes.'''
-        # return set(cls.__subclasses__()).union( [s for c in cls.__subclasses__() for s in c.allSubclasses()]) 
-    
     @classmethod
     def getBoardClasses(cls):
         '''Returns all known board classes
-        
+    
         :return: All known board classes
         :rtype: dict 
         '''
         return dict([(c.number,c) for c in cls.__subclasses__()])
     
+    @classmethod
+    def getSubclasses(cls):
+        '''Returns all sub-classes recursively
+        
+        Returns:
+            set: All sub-classes of this class.
+        '''
+        return set(cls.__subclasses__()).union( [s for c in cls.__subclasses__() for s in c.getSubclasses()])  
+    
     @classmethod
     def getName(cls):
         '''Returns the board type name
         :return: The board type name
         :rtype: str
         '''
-        return f"MB-{cls.number}"+cls.number
+        if cls.ext is not None:
+            return f"MB-{cls.number}-{cls.ext}"
+        else:
+            return f"MB-{cls.number}"
 
     @classmethod
     def getCode(cls):
@@ -71,7 +81,10 @@ class BaseDBoard(object):
         :return: The board type code
         :rtype: str
         '''
-        return f"mb{cls.number}"
+        if cls.ext is not None:
+            return f"mb{cls.number}{cls.ext.lower()}"
+        else:
+            return f"mb{cls.number}"
 
     def __init__(self, dapi, dmode=DBoardPreferredDapiMode.REGISTER):
         '''Constructor'''
@@ -783,6 +796,11 @@ class DBoard(BaseDBoard):
     '''Generic class board.
     
     This class is used when the type of card could not be determined.
+    
+    
+    .. inheritance-diagram:: DBoard
+        :parts: 1
+    
     ''' 
     number = '00'
     '''Board type number'''
