@@ -17,7 +17,12 @@ class DacSignalMb30(DacSignal):
     
 
 class Board30(DBoard):
-    '''Class for MB-30 Dassym's board.'''
+    '''Class for MB-30 Dassym's board.
+    
+    .. inheritance-diagram:: Board30
+        :parts: 1
+    
+    '''
     
     number = '30'
     '''Board type number (str)'''
