@@ -15,7 +15,12 @@ class DacSignalMb92(DacSignal):
     PWM_OPENING = 4
 
 class Board92(DBoard):
-    '''Class for MB-92 Dassym's board.'''
+    '''Class for MB-92 Dassym's board.
+
+    .. inheritance-diagram:: Board92
+        :parts: 1
+    
+    '''
     
     number = '92'
     '''Board type number (str)'''
@@ -25,4 +30,8 @@ class Board92(DBoard):
     def __init__(self, dapi, dmode=DBoardPreferredDapiMode.REGISTER):
         '''Constructor'''
         super().__init__(dapi, dmode)
-        self.speed_range.set(100,40000)         
\ No newline at end of file
+        self.speed_range.set(100,40000)         
+        
+class Board92B(Board92):
+    ext = 'B'
+        
\ No newline at end of file
