@@ -233,9 +233,9 @@ class BitFieldReader(BaseRegReader):
         if name is not None:
             self._element = dreg.RegBit(name, self.parent, addr, size, descriptions=getXmlDescriptions(xbit),)
             self._element.choices = {}
-#             for xchoice in xbit.findall('choice'):
-#                 v = int(xchoice.get('value','0'),0)
-#                 self._element.choices[v] = dreg.RegBitChoice(self._element,xchoice.get('name'), v, descr=getXmlDescription(xchoice), shortname=xchoice.get('shortname'))
+            for xchoice in xbit.findall('choice'):
+                v = int(xchoice.get('value','0'),0)
+                self._element.choices[v] = xchoice.get('name')
         else: 
             self._element = dreg.ReservedRegBit('Reserved', self.parent, addr, size, descriptions=getXmlDescriptions(xbit),)
         return self.element
