@@ -77,29 +77,34 @@ class Register(BaseRegElement):
         return chr(self.value // 256) + chr( self.value & 0xff )  
     
     def alter(self, value):
-        self.set(value, modified=True)
+        return self.set(value)
     
-    def set(self, value, modified=False):
-        self._undefined = False
-        self._modified = modified
-        if self._undefined or (self.container.values[self.addr] != value):
-            old = self.container.values[self.addr] 
+    def internalSet(self, value, modified=False):
+        old = self.container.values[self.addr]
+        self._modified = modified and old != value 
+        if self._undefined or old != value:
             self.container.values[self.addr] = value
             self._valueChanged(old)
-            self._undefined = False
-        
+        self._undefined = False
+        return value
+            
+    def set(self, value):
+        return self.internalSet(value, True)
+    
+    def setMin(self):
+        return self.set(self.min)
+
+    def setMax(self):
+        return self.set(self.max)
+    
+    def clear(self):
+        return self.set(0)
+    
     def get(self):
         if self._undefined:
             raise DRegUndefinedError(self, 'get', 'Undefined value in register '+self.name)
         return self.container.values[self.addr]      
     
-    # def connect(self, callback):
-    #     if all(x != callback for x in self._callback_list):
-    #         self._callback_list.append(callback)            
-    #
-    # def disconnect(self, callback):
-    #     self._callback_list.remove(callback) 
-        
     @property
     def access(self):
         '''The register access mode'''
@@ -111,10 +116,7 @@ class Register(BaseRegElement):
         
 class ReservedRegister(Register):
     
-        pass
-#     def get(self):
-#         raise  Exception('Get value of reserved register is not allowed!') 
-
+    pass
 
 class RegisterBits(object):
     
@@ -288,12 +290,17 @@ class RegisterArray(Register):
             r.setAddr(self.addr+i)
     
     def alter(self, values):
-        self.set(values, True)
-    
-    def set(self, values, modified=False):
+        return self.set(values)
+        
+    def set(self, values):
+        for i, v in enumerate(values):
+            self._regs[i].set(v)
+        self._undefined = False
+        
+    def internalSet(self, values, modified=False):
         self._modified = modified
         for i, v in enumerate(values):
-            self._regs[i].set(v, modified)
+            self._regs[i].internalSet(v, modified)
         self._undefined = False
         
     def get(self):
@@ -363,21 +370,22 @@ class RegBit(BaseRegElement):
     def _stringData(self, lang=None):
         return "{0:d}".format(self.get())
     
-    def alter(self, value):
-        self.set(value, True)
-        
-    def set(self, value=1, modified=False):
-        assert value >= 0 and value < (1<<self._size), 'RegBit.set:{} is an invalid value for the flag {}.{}'.format(value,self._owner.reg.name,self.name)
-        self._parent.set((self._parent.value & ~self._mask) | (value << self.addr),modified)
-        return self._parent.value
+    def internalSet(self, value, modified=False):
+        assert value >= 0 and value < (1<<self._size), 'RegBit.internalSet:{} is an invalid value for the flag {}.{}'.format(value,self._owner.reg.name,self.name)
+        return self._parent.internalSet((self._parent.value & ~self._mask) | (value << self.addr), modified)
     
-    def toggle(self, modified=False):
-        self._parent.set(self._parent.value ^ self._mask,modified)
-        return self._parent.value
+    def alter(self, value):
+        return self.set(value)
+        
+    def set(self, value=1):
+        assert value >= 0 and value < (1<<self._size), 'RegBit.set:{} is an invalid value for the flag {}.{}'.format(value,self._owner.reg.name,self.name)
+        return self._parent.set((self._parent.value & ~self._mask) | (value << self.addr) )
+    
+    def toggle(self):
+        return self._parent.set(self._parent.value ^ self._mask)
         
     def clear(self):
-        self.set(0, False)
-        return self._parent.value
+        return self.set(0)
         
     def get(self):
         return (self._parent.value & self._mask) >> self.addr
